/* 
Code: Basic RBC Model
Author: Michael Curran
Purpose: Illustrate basic RBC simulation in Dynare
Version: Nov 1, 2013
*/

//------------------------------------------------------------------------
// 0. Housekeeping (close all graphic windows)
//------------------------------------------------------------------------

close all;

//------------------------------------------------------------------------
// 1.(a) Preamble: Defining variables
//------------------------------------------------------------------------

var y c k l z;          // Endogenous variables
varexo e;               // Exogenous variables

parameters beta gamma delta alpha rho theta;

//------------------------------------------------------------------------
// 1.(b) Preamble: Calibration
//------------------------------------------------------------------------

alpha=0.4;          // labour share of income
beta=0.95;          // discount factor
delta=0.1;          // depreciation
gamma=2;              // taste parameter
rho=0.95;           // persistence of technology
theta=1;            // parameter governing diminishing marginal utility 

//------------------------------------------------------------------------
// 2. Model
//------------------------------------------------------------------------

model;
c^-theta = beta*c(+1)^-theta*(alpha*exp(z(+1))*k^(alpha-1)*l(+1)^(1-alpha)+1-delta);
gamma=c^-theta*(1-alpha)*exp(z)*k(-1)^alpha*l^-alpha;
c+k=exp(z)*k(-1)^alpha*l^(1-alpha)+(1-delta)*k(-1);
y=exp(z)*k(-1)^alpha*l^(1-alpha);
z=rho*z(-1)+e;
end;

//------------------------------------------------------------------------
// 3. Initial Values
//------------------------------------------------------------------------

initval;
    k=2;
    c=0.5;
    l=0.3;
    z=0;
    e=0;
end;

//------------------------------------------------------------------------
// 4. Shocks
//------------------------------------------------------------------------

shocks;
    var e=1;
end;

steady;

//------------------------------------------------------------------------
// 5. Computation and results
//------------------------------------------------------------------------

stoch_simul(hp_filter=1600, order=1);